@@ -97,6 +97,13 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_flush, 0, 0, 0)
     ZEND_ARG_INFO(0, async)
 ZEND_END_ARG_INFO()
 
+ZEND_BEGIN_ARG_INFO_EX(arginfo_scan, 0, 0, 2)
+	ZEND_ARG_INFO(1, iterator)
+	ZEND_ARG_INFO(0, node)
+	ZEND_ARG_INFO(0, pattern)
+	ZEND_ARG_INFO(0, count)
+ZEND_END_ARG_INFO()
+
 zend_function_entry redis_array_functions[] = {
      PHP_ME(RedisArray, __call, arginfo_call, ZEND_ACC_PUBLIC)
      PHP_ME(RedisArray, __construct, arginfo_ctor, ZEND_ACC_PUBLIC)
@@ -114,6 +121,7 @@ zend_function_entry redis_array_functions[] = {
      PHP_ME(RedisArray, flushall, arginfo_flush, ZEND_ACC_PUBLIC)
      PHP_ME(RedisArray, flushdb, arginfo_flush, ZEND_ACC_PUBLIC)
      PHP_ME(RedisArray, getOption, arginfo_getopt, ZEND_ACC_PUBLIC)
+     PHP_ME(RedisArray, hscan, arginfo_kscan, ZEND_ACC_PUBLIC)
      PHP_ME(RedisArray, info, arginfo_void, ZEND_ACC_PUBLIC)
      PHP_ME(RedisArray, keys, arginfo_keys, ZEND_ACC_PUBLIC)
      PHP_ME(RedisArray, mget, arginfo_mget, ZEND_ACC_PUBLIC)
@@ -121,10 +129,13 @@ zend_function_entry redis_array_functions[] = {
      PHP_ME(RedisArray, multi, arginfo_multi, ZEND_ACC_PUBLIC)
      PHP_ME(RedisArray, ping, arginfo_void, ZEND_ACC_PUBLIC)
      PHP_ME(RedisArray, save, arginfo_void, ZEND_ACC_PUBLIC)
+     PHP_ME(RedisArray, scan, arginfo_scan, ZEND_ACC_PUBLIC)
      PHP_ME(RedisArray, select, arginfo_select, ZEND_ACC_PUBLIC)
      PHP_ME(RedisArray, setOption,arginfo_setopt, ZEND_ACC_PUBLIC)
+     PHP_ME(RedisArray, sscan, arginfo_kscan, ZEND_ACC_PUBLIC)
      PHP_ME(RedisArray, unlink, arginfo_void, ZEND_ACC_PUBLIC)
      PHP_ME(RedisArray, unwatch, arginfo_void, ZEND_ACC_PUBLIC)
+     PHP_ME(RedisArray, zscan, arginfo_kscan, ZEND_ACC_PUBLIC)
      PHP_MALIAS(RedisArray, delete, del, arginfo_del, ZEND_ACC_PUBLIC)
      PHP_MALIAS(RedisArray, getMultiple, mget, arginfo_mget, ZEND_ACC_PUBLIC)
      PHP_FE_END
@@ -1095,7 +1106,8 @@ ra_generic_del(INTERNAL_FUNCTION_PARAMETERS, char *kw, int kw_len)
         /* copy all elements to z_keys */
         array_init(&z_keys);
         for (i = 0; i < argc; ++i) {
-            add_next_index_zval(&z_keys, &z_args[i]);
+            ZVAL_ZVAL(&z_ret, &z_args[i], 1, 0);
+            add_next_index_zval(&z_keys, &z_ret);
         }
         free_zkeys = 1;
     }
@@ -1144,7 +1156,8 @@ ra_generic_del(INTERNAL_FUNCTION_PARAMETERS, char *kw, int kw_len)
         array_init(&z_argarray);
         for(i = 0; i < argc; ++i) {
             if (pos[i] == n) {
-                add_next_index_zval(&z_argarray, argv[i]);
+                ZVAL_ZVAL(&z_ret, argv[i], 1, 0);
+                add_next_index_zval(&z_argarray, &z_ret);
                 found++;
             }
         }
@@ -1193,6 +1206,86 @@ PHP_METHOD(RedisArray, unlink) {
     ra_generic_del(INTERNAL_FUNCTION_PARAM_PASSTHRU, "UNLINK", sizeof("UNLINK") - 1);
 }
 
+static void
+ra_generic_scan_cmd(INTERNAL_FUNCTION_PARAMETERS, const char *kw, int kw_len)
+{
+    RedisArray *ra;
+    zend_string *key, *pattern = NULL;
+    zval *object, *redis_inst, *z_iter, z_fun, z_args[4];
+    zend_long count = 0;
+
+    if (zend_parse_method_parameters(ZEND_NUM_ARGS(), getThis(), "OSz/|S!l",
+            &object, redis_array_ce, &key, &z_iter, &pattern, &count) == FAILURE) {
+        RETURN_FALSE;
+    }
+
+    if ((ra = redis_array_get(object)) == NULL) {
+        RETURN_FALSE;
+    }
+
+    if ((redis_inst = ra_find_node(ra, ZSTR_VAL(key), ZSTR_LEN(key), NULL)) == NULL) {
+        php_error_docref(NULL, E_ERROR, "Could not find any redis servers for this key.");
+        RETURN_FALSE;
+    }
+
+    ZVAL_STR(&z_args[0], key);
+    ZVAL_NEW_REF(&z_args[1], z_iter);
+    if (pattern) ZVAL_STR(&z_args[2], pattern);
+    ZVAL_LONG(&z_args[3], count);
+
+    ZVAL_STRINGL(&z_fun, kw, kw_len);
+    call_user_function(&redis_ce->function_table, redis_inst, &z_fun, return_value, ZEND_NUM_ARGS(), z_args);
+    zval_dtor(&z_fun);
+
+    ZVAL_ZVAL(z_iter, &z_args[1], 0, 1);
+}
+
+PHP_METHOD(RedisArray, hscan)
+{
+    ra_generic_scan_cmd(INTERNAL_FUNCTION_PARAM_PASSTHRU, "HSCAN", sizeof("HSCAN") - 1);
+}
+
+PHP_METHOD(RedisArray, sscan)
+{
+    ra_generic_scan_cmd(INTERNAL_FUNCTION_PARAM_PASSTHRU, "SSCAN", sizeof("SSCAN") - 1);
+}
+
+PHP_METHOD(RedisArray, zscan)
+{
+    ra_generic_scan_cmd(INTERNAL_FUNCTION_PARAM_PASSTHRU, "ZSCAN", sizeof("ZSCAN") - 1);
+}
+
+PHP_METHOD(RedisArray, scan)
+{
+    RedisArray *ra;
+    zend_string *host, *pattern = NULL;
+    zval *object, *redis_inst, *z_iter, z_fun, z_args[3];
+    zend_long count = 0;
+
+    if (zend_parse_method_parameters(ZEND_NUM_ARGS(), getThis(), "Oz/S|S!l",
+            &object, redis_array_ce, &z_iter, &host, &pattern, &count) == FAILURE) {
+        RETURN_FALSE;
+    }
+
+    if ((ra = redis_array_get(object)) == NULL) {
+        RETURN_FALSE;
+    }
+
+    if ((redis_inst = ra_find_node_by_name(ra, host)) == NULL) {
+        RETURN_FALSE;
+    }
+
+    ZVAL_NEW_REF(&z_args[0], z_iter);
+    if (pattern) ZVAL_STR(&z_args[1], pattern);
+    ZVAL_LONG(&z_args[2], count);
+
+    ZVAL_STRING(&z_fun, "SCAN");
+    call_user_function(&redis_ce->function_table, redis_inst, &z_fun, return_value, ZEND_NUM_ARGS() - 1, z_args);
+    zval_dtor(&z_fun);
+
+    ZVAL_ZVAL(z_iter, &z_args[0], 0, 1);
+}
+
 PHP_METHOD(RedisArray, multi)
 {
     zval *object;
