@@ -5,8 +5,18 @@
 #include <php.h>
 #include <stddef.h>
 
+/* Redis cluster hash slots and N-1 which we'll use to find it */
+#define REDIS_CLUSTER_SLOTS 16384
+#define REDIS_CLUSTER_MOD   (REDIS_CLUSTER_SLOTS-1)
+
 /* Get attached object context */
-#define GET_CONTEXT() PHPREDIS_ZVAL_GET_OBJECT(redisCluster, getThis())
+#if (PHP_MAJOR_VERSION < 7)
+#define GET_CONTEXT() \
+    ((redisCluster*)zend_object_store_get_object(getThis() TSRMLS_CC))
+#else
+#define GET_CONTEXT() \
+    ((redisCluster *)((char *)Z_OBJ_P(getThis()) - XtOffsetOf(redisCluster, std)))
+#endif
 
 /* Command building/processing is identical for every command */
 #define CLUSTER_BUILD_CMD(name, c, cmd, cmd_len, slot) \
@@ -60,7 +70,7 @@
                              &cmd_len, &slot, &ctx)==FAILURE) { \
         RETURN_FALSE; \
     } \
-    if(cluster_send_command(c,slot,cmd,cmd_len)<0 || c->err!=NULL) {\
+    if(cluster_send_command(c,slot,cmd,cmd_len TSRMLS_CC)<0 || c->err!=NULL) {\
         efree(cmd); \
         RETURN_FALSE; \
     } \
@@ -80,7 +90,7 @@
                &slot,&ctx)==FAILURE) { \
         RETURN_FALSE; \
     } \
-    if(cluster_send_command(c,slot,cmd,cmd_len)<0 || c->err!=NULL) { \
+    if(cluster_send_command(c,slot,cmd,cmd_len TSRMLS_CC)<0 || c->err!=NULL) { \
         efree(cmd); \
         RETURN_FALSE; \
     } \
@@ -91,15 +101,27 @@
     } \
     resp_func(INTERNAL_FUNCTION_PARAM_PASSTHRU, c, ctx); 
 
-/* Create cluster context */
-zend_object *create_cluster_context(zend_class_entry *class_type);
+/* For the creation of RedisCluster specific exceptions */
+PHP_REDIS_API zend_class_entry *rediscluster_get_exception_base(int root TSRMLS_DC);
 
+#if (PHP_MAJOR_VERSION < 7)
+/* Create cluster context */
+zend_object_value create_cluster_context(zend_class_entry *class_type TSRMLS_DC);
+/* Free cluster context struct */
+void free_cluster_context(void *object TSRMLS_DC);
+#else
+/* Create cluster context */
+zend_object *create_cluster_context(zend_class_entry *class_type TSRMLS_DC);
 /* Free cluster context struct */
 void free_cluster_context(zend_object *object);
+#endif
+
+
+/* Inittialize our class with PHP */
+void init_rediscluster(TSRMLS_D);
 
 /* RedisCluster method implementation */
 PHP_METHOD(RedisCluster, __construct);
-PHP_METHOD(RedisCluster, acl);
 PHP_METHOD(RedisCluster, close);
 PHP_METHOD(RedisCluster, get);
 PHP_METHOD(RedisCluster, set);
