@@ -854,7 +854,7 @@ static char *cluster_session_key(redisCluster *c, const char *key, int keylen,
 
 PS_OPEN_FUNC(rediscluster) {
     redisCluster *c;
-    zval z_conf, *zv;
+    zval z_conf, *zv, *context;
     HashTable *ht_conf, *ht_seeds;
     double timeout = 0, read_timeout = 0;
     int persistent = 0, failover = REDIS_FAILOVER_NONE;
@@ -907,6 +907,7 @@ PS_OPEN_FUNC(rediscluster) {
 
     #define CLUSTER_SESSION_CLEANUP() \
         if (hash) zend_string_release(hash); \
+        if (failstr) zend_string_release(failstr); \
         if (prefix) zend_string_release(prefix); \
         if (user) zend_string_release(user); \
         if (pass) zend_string_release(pass); \
@@ -918,7 +919,6 @@ PS_OPEN_FUNC(rediscluster) {
     if (seeds == NULL) {
         php_error_docref(NULL, E_WARNING, "No valid seeds detected");
         CLUSTER_SESSION_CLEANUP();
-        zval_dtor(&z_conf);
         return FAILURE;
     }
 
@@ -932,6 +932,10 @@ PS_OPEN_FUNC(rediscluster) {
 
     redis_sock_set_auth(c->flags, user, pass);
 
+    if ((context = REDIS_HASH_STR_FIND_TYPE_STATIC(ht_conf, "stream", IS_ARRAY)) != NULL) {
+        redis_sock_set_stream_context(c->flags, context);
+    }
+
     /* First attempt to load from cache */
     if (CLUSTER_CACHING_ENABLED()) {
         hash = cluster_hash_seeds(seeds, nseeds);
