@@ -49,6 +49,13 @@ class Redis_Cluster_Test extends Redis_Test {
     public function testTlsConnect() { return $this->markTestSkipped(); }
     public function testInvalidAuthArgs() { return $this->markTestSkipped(); }
 
+    public function testlMove() { return $this->markTestSkipped(); }
+    public function testsMisMember() { return $this->markTestSkipped(); }
+    public function testzDiff() { return $this->markTestSkipped(); }
+    public function testzDiffStore() { return $this->markTestSkipped(); }
+    public function testzMscore() { return $this->marktestSkipped(); }
+    public function testCopy() { return $this->marktestSkipped(); }
+
     /* Session locking feature is currently not supported in in context of Redis Cluster.
        The biggest issue for this is the distribution nature of Redis cluster */
     public function testSession_lockKeyCorrect() { return $this->markTestSkipped(); }
